Internal function called by fit_peel for i in 1–n.peels.
Creates the input for the model peeling off i years of data (calls fit_tmb).
Reduces the year dimension of all data, parameters, maps, so that one can project correctly from the peeled model.
Arguments
- input
list containing data, parameters, map, and random elements (output from
prepare_wham_input). NOT from prepare_projection or project_wham- years_peeled
which of input$years to peel from the model input
- retro
(T/F) whether this is for a retro peel (Default = TRUE)