Set up observation vector that is used by the model for likelihood calculations and one-step-ahead residuals.
Source:R/set_osa_obs.R
set_osa_obs.RdSet up observation vector that is used by the model for likelihood calculations and one-step-ahead residuals.
Arguments
- input
list containing data, parameters, map, and random elements (output from
wham::prepare_wham_input)